@@ -9,6 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import typing as ty
+
 from openstack.common import metadata
 from openstack import format
 from openstack import resource
@@ -114,15 +117,38 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         body = {'os-set_bootable': {'bootable': bootable}}
         self._action(session, body)
 
-    def reset_status(self, session, status, attach_status, migration_status):
+    def set_readonly(self, session, readonly):
+        """Set volume readonly flag"""
+        body = {'os-update_readonly_flag': {'readonly': readonly}}
+        self._action(session, body)
+
+    def set_image_metadata(self, session, metadata):
+        """Sets image metadata key-value pairs on the volume"""
+        body = {'os-set_image_metadata': metadata}
+        self._action(session, body)
+
+    def delete_image_metadata(self, session):
+        """Remove all image metadata from the volume"""
+        for key in self.metadata:
+            body = {'os-unset_image_metadata': key}
+            self._action(session, body)
+
+    def delete_image_metadata_item(self, session, key):
+        """Remove a single image metadata from the volume"""
+        body = {'os-unset_image_metadata': key}
+        self._action(session, body)
+
+    def reset_status(
+        self, session, status=None, attach_status=None, migration_status=None
+    ):
         """Reset volume statuses (admin operation)"""
-        body = {
-            'os-reset_status': {
-                'status': status,
-                'attach_status': attach_status,
-                'migration_status': migration_status,
-            }
-        }
+        body: ty.Dict[str, ty.Dict[str, str]] = {'os-reset_status': {}}
+        if status:
+            body['os-reset_status']['status'] = status
+        if attach_status:
+            body['os-reset_status']['attach_status'] = attach_status
+        if migration_status:
+            body['os-reset_status']['migration_status'] = migration_status
         self._action(session, body)
 
     def attach(self, session, mountpoint, instance):
@@ -144,7 +170,7 @@ class Volume(resource.Resource, metadata.MetadataMixin):
 
     def unmanage(self, session):
         """Unmanage volume"""
-        body = {'os-unmanage': {}}
+        body = {'os-unmanage': None}
 
         self._action(session, body)
 
@@ -184,7 +210,7 @@ class Volume(resource.Resource, metadata.MetadataMixin):
 
     def force_delete(self, session):
         """Force volume deletion"""
-        body = {'os-force_delete': {}}
+        body = {'os-force_delete': None}
 
         self._action(session, body)
 
