@@ -16,7 +16,7 @@ import warnings
 
 import jsonpatch
 
-from openstack.baremetal.v1._proxy import Proxy
+from openstack.cloud import openstackcloud
 from openstack import exceptions
 from openstack import warnings as os_warnings
 
@@ -41,8 +41,7 @@ def _normalize_port_list(nics):
     return ports
 
 
-class BaremetalCloudMixin:
-    baremetal: Proxy
+class BaremetalCloudMixin(openstackcloud._OpenStackCloudMixin):
 
     def list_nics(self):
         """Return a list of all bare metal ports."""
@@ -463,9 +462,9 @@ class BaremetalCloudMixin:
         :raises: :exc:`~openstack.exceptions.ValidationException`
         """
         if for_deploy:
-            ifaces = ('boot', 'deploy', 'management', 'power')
+            ifaces = ['boot', 'deploy', 'management', 'power']
         else:
-            ifaces = ('power',)
+            ifaces = ['power']
         self.baremetal.validate_node(name_or_id, required=ifaces)
 
     def validate_node(self, uuid):
