@@ -17,6 +17,7 @@ import hmac
 import json
 import os
 import time
+import typing as ty
 from urllib import parse
 
 from openstack import _log
@@ -156,7 +157,7 @@ class Proxy(proxy.Proxy):
         :param container: The value can be either the name of a container or a
             :class:`~openstack.object_store.v1.container.Container` instance.
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            :class:`~openstack.exceptions.NotFoundException` will be raised when
             the container does not exist. When set to ``True``, no exception
             will be set when attempting to delete a nonexistent server.
 
@@ -173,7 +174,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.object_store.v1.container.Container` instance.
 
         :returns: One :class:`~openstack.object_store.v1.container.Container`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         return self._head(_container.Container, container)
@@ -278,7 +279,7 @@ class Proxy(proxy.Proxy):
 
         :returns: Instance of the
             :class:`~openstack.object_store.v1.obj.Object` objects.
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         container_name = self._get_container_name(obj=obj, container=container)
@@ -322,7 +323,7 @@ class Proxy(proxy.Proxy):
         :param container: The value can be the name of a container or a
             :class:`~openstack.object_store.v1.container.Container` instance.
 
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         container_name = self._get_container_name(obj=obj, container=container)
@@ -339,7 +340,7 @@ class Proxy(proxy.Proxy):
         :param container: The value can be the name of a container or a
             :class:`~openstack.object_store.v1.container.Container` instance.
 
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         :returns: An iterator that iterates over chunk_size bytes
         """
@@ -394,7 +395,8 @@ class Proxy(proxy.Proxy):
         :param metadata: This dict will get changed into headers that set
             metadata of the object
 
-        :raises: ``OpenStackCloudException`` on operation error.
+        :raises: ``:class:`~openstack.exceptions.SDKException``` on operation
+            error.
         """
         if data is not None and filename:
             raise ValueError(
@@ -489,7 +491,7 @@ class Proxy(proxy.Proxy):
         :param container: The value can be the ID of a container or a
             :class:`~openstack.object_store.v1.container.Container` instance.
         :param bool ignore_missing: When set to ``False``
-            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            :class:`~openstack.exceptions.NotFoundException` will be raised when
             the object does not exist.  When set to ``True``, no exception will
             be set when attempting to delete a nonexistent server.
 
@@ -513,7 +515,7 @@ class Proxy(proxy.Proxy):
             :class:`~openstack.object_store.v1.container.Container` instance.
 
         :returns: One :class:`~openstack.object_store.v1.obj.Object`
-        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+        :raises: :class:`~openstack.exceptions.NotFoundException`
             when no resource can be found.
         """
         container_name = self._get_container_name(obj, container)
@@ -650,7 +652,7 @@ class Proxy(proxy.Proxy):
                     # While Object Storage usually expects the name to be
                     # urlencoded in most requests, the SLO manifest requires
                     # plain object names instead.
-                    path='/{name}'.format(name=parse.unquote(name)),
+                    path=f'/{parse.unquote(name)}',
                     size_bytes=segment.length,
                 )
             )
@@ -768,15 +770,17 @@ class Proxy(proxy.Proxy):
         try:
             # caps = self.get_object_capabilities()
             caps = self.get_info()
-        except exceptions.SDKException as e:
-            if e.response.status_code in (404, 412):
-                server_max_file_size = DEFAULT_MAX_FILE_SIZE
-                self._connection.log.info(
-                    "Swift capabilities not supported. "
-                    "Using default max file size."
-                )
-            else:
-                raise
+        except (
+            exceptions.NotFoundException,
+            exceptions.PreconditionFailedException,
+        ):
+            server_max_file_size = DEFAULT_MAX_FILE_SIZE
+            self._connection.log.info(
+                "Swift capabilities not supported. "
+                "Using default max file size."
+            )
+        except exceptions.SDKException:
+            raise
         else:
             server_max_file_size = caps.swift.get('max_file_size', 0)
             min_segment_size = caps.slo.get('min_segment_size', 0)
@@ -804,7 +808,7 @@ class Proxy(proxy.Proxy):
                 continue
             name = self._object_name_from_url(result.url)
             for entry in manifest:
-                if entry['path'] == '/{name}'.format(name=parse.unquote(name)):
+                if entry['path'] == f'/{parse.unquote(name)}':
                     entry['etag'] = result.headers['Etag']
 
     def get_info(self):
@@ -927,15 +931,14 @@ class Proxy(proxy.Proxy):
         endpoint = parse.urlparse(self.get_endpoint())
         path = '/'.join([endpoint.path, res.name, object_prefix])
 
-        data = '%s\n%s\n%s\n%s\n%s' % (
+        data = '{}\n{}\n{}\n{}\n{}'.format(
             path,
             redirect_url,
             max_file_size,
             max_upload_count,
             expires,
         )
-        data = data.encode('utf8')
-        sig = hmac.new(temp_url_key, data, sha1).hexdigest()
+        sig = hmac.new(temp_url_key, data.encode(), sha1).hexdigest()
 
         return (expires, sig)
 
@@ -991,18 +994,17 @@ class Proxy(proxy.Proxy):
                     try:
                         t = time.strptime(seconds, f)
                     except ValueError:
-                        t = None
+                        continue
+
+                    if f == EXPIRES_ISO8601_FORMAT:
+                        timestamp = timegm(t)
                     else:
-                        if f == EXPIRES_ISO8601_FORMAT:
-                            timestamp = timegm(t)
-                        else:
-                            # Use local time if UTC designator is missing.
-                            timestamp = int(time.mktime(t))
+                        # Use local time if UTC designator is missing.
+                        timestamp = int(time.mktime(t))
 
-                        absolute = True
-                        break
-
-                if t is None:
+                    absolute = True
+                    break
+                else:
                     raise ValueError()
             else:
                 if not timestamp.is_integer():
@@ -1045,6 +1047,7 @@ class Proxy(proxy.Proxy):
                 method.upper(),
             )
 
+        expiration: ty.Union[float, int]
         if not absolute:
             expiration = _get_expiration(timestamp)
         else:
@@ -1064,7 +1067,7 @@ class Proxy(proxy.Proxy):
                     raise ValueError('ip_range must be representable as UTF-8')
             hmac_parts.insert(0, "ip=%s" % ip_range)
 
-        hmac_body = u'\n'.join(hmac_parts)
+        hmac_body = '\n'.join(hmac_parts)
 
         temp_url_key = self._check_temp_url_key(temp_url_key=temp_url_key)
 
@@ -1073,19 +1076,23 @@ class Proxy(proxy.Proxy):
         ).hexdigest()
 
         if iso8601:
-            expiration = time.strftime(
+            exp = time.strftime(
                 EXPIRES_ISO8601_FORMAT, time.gmtime(expiration)
             )
+        else:
+            exp = str(expiration)
 
-        temp_url = u'{path}?temp_url_sig={sig}&temp_url_expires={exp}'.format(
-            path=path_for_body, sig=sig, exp=expiration
+        temp_url = '{path}?temp_url_sig={sig}&temp_url_expires={exp}'.format(
+            path=path_for_body,
+            sig=sig,
+            exp=exp,
         )
 
         if ip_range:
-            temp_url += u'&temp_url_ip_range={}'.format(ip_range)
+            temp_url += f'&temp_url_ip_range={ip_range}'
 
         if prefix:
-            temp_url += u'&temp_url_prefix={}'.format(parts[4])
+            temp_url += f'&temp_url_prefix={parts[4]}'
         # Have return type match path from caller
         if isinstance(path, bytes):
             return temp_url.encode('utf-8')
@@ -1142,7 +1149,7 @@ class Proxy(proxy.Proxy):
             return
 
         is_bulk_delete_supported = False
-        bulk_delete_max_per_request = None
+        bulk_delete_max_per_request = 1
         try:
             caps = self.get_info()
         except exceptions.SDKException:
