@@ -21,7 +21,8 @@ from openstack.block_storage.v2 import snapshot
 from openstack.block_storage.v2 import stats
 from openstack.block_storage.v2 import type
 from openstack.block_storage.v2 import volume
-from openstack import resource
+from openstack.identity.v3 import project
+from openstack import proxy as proxy_base
 from openstack.tests.unit import test_proxy_base
 
 
@@ -137,6 +138,22 @@ class TestVolumeActions(TestVolumeProxy):
             expected_args=[self.proxy, "new-size"],
         )
 
+    def test_volume_set_readonly_no_argument(self):
+        self._verify(
+            "openstack.block_storage.v2.volume.Volume.set_readonly",
+            self.proxy.set_volume_readonly,
+            method_args=["value"],
+            expected_args=[self.proxy, True],
+        )
+
+    def test_volume_set_readonly_false(self):
+        self._verify(
+            "openstack.block_storage.v2.volume.Volume.set_readonly",
+            self.proxy.set_volume_readonly,
+            method_args=["value", False],
+            expected_args=[self.proxy, False],
+        )
+
     def test_volume_set_bootable(self):
         self._verify(
             "openstack.block_storage.v2.volume.Volume.set_bootable_status",
@@ -421,6 +438,9 @@ class TestType(TestVolumeProxy):
     def test_type_get(self):
         self.verify_get(self.proxy.get_type, type.Type)
 
+    def test_type_find(self):
+        self.verify_find(self.proxy.find_type, type.Type)
+
     def test_types(self):
         self.verify_list(self.proxy.types, type.Type)
 
@@ -526,19 +546,17 @@ class TestQuotaSet(TestVolumeProxy):
             expected_kwargs={'user_id': 'uid'},
         )
 
-    @mock.patch('openstack.proxy.Proxy._get_resource', autospec=True)
-    def test_quota_set_update(self, gr_mock):
-        gr_mock.return_value = resource.Resource()
-        gr_mock.commit = mock.Mock()
+    @mock.patch.object(proxy_base.Proxy, '_get_resource')
+    def test_quota_set_update(self, mock_get):
+        fake_project = project.Project(id='prj')
+        mock_get.side_effect = [fake_project]
+
         self._verify(
-            'openstack.resource.Resource.commit',
+            'openstack.proxy.Proxy._update',
             self.proxy.update_quota_set,
-            method_args=['qs'],
-            method_kwargs={
-                'query': {'user_id': 'uid'},
-                'a': 'b',
-            },
-            expected_args=[self.proxy],
-            expected_kwargs={'user_id': 'uid'},
+            method_args=['prj'],
+            method_kwargs={'volumes': 123},
+            expected_args=[quota_set.QuotaSet, None],
+            expected_kwargs={'project_id': 'prj', 'volumes': 123},
         )
-        gr_mock.assert_called_with(self.proxy, quota_set.QuotaSet, 'qs', a='b')
+        mock_get.assert_called_once_with(project.Project, 'prj')
