@@ -10,10 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
 import uuid
 
 from openstack.network.v2 import qos_bandwidth_limit_rule
+from openstack.tests.unit import base
+
 
 EXAMPLE = {
     'id': 'IDENTIFIER',
@@ -24,19 +25,18 @@ EXAMPLE = {
 }
 
 
-class TestQoSBandwidthLimitRule(testtools.TestCase):
-
+class TestQoSBandwidthLimitRule(base.TestCase):
     def test_basic(self):
         sot = qos_bandwidth_limit_rule.QoSBandwidthLimitRule()
         self.assertEqual('bandwidth_limit_rule', sot.resource_key)
         self.assertEqual('bandwidth_limit_rules', sot.resources_key)
         self.assertEqual(
             '/qos/policies/%(qos_policy_id)s/bandwidth_limit_rules',
-            sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
+            sot.base_path,
+        )
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
