@@ -236,7 +236,7 @@ class TestProxyDelete(base.TestCase):
         self.assertEqual(rv, self.fake_id)
 
     def test_delete_ignore_missing(self):
-        self.res.delete.side_effect = exceptions.ResourceNotFound(
+        self.res.delete.side_effect = exceptions.NotFoundException(
             message="test", http_status=404
         )
 
@@ -244,12 +244,12 @@ class TestProxyDelete(base.TestCase):
         self.assertIsNone(rv)
 
     def test_delete_NotFound(self):
-        self.res.delete.side_effect = exceptions.ResourceNotFound(
+        self.res.delete.side_effect = exceptions.NotFoundException(
             message="test", http_status=404
         )
 
         self.assertRaisesRegex(
-            exceptions.ResourceNotFound,
+            exceptions.NotFoundException,
             # TODO(shade) The mocks here are hiding the thing we want to test.
             "test",
             self.sot._delete,
@@ -467,12 +467,12 @@ class TestProxyGet(base.TestCase):
         self.assertEqual(rv, self.fake_result)
 
     def test_get_not_found(self):
-        self.res.fetch.side_effect = exceptions.ResourceNotFound(
+        self.res.fetch.side_effect = exceptions.NotFoundException(
             message="test", http_status=404
         )
 
         self.assertRaisesRegex(
-            exceptions.ResourceNotFound,
+            exceptions.NotFoundException,
             "test",
             self.sot._get,
             RetrieveableResource,
